#
# spec file for package python-fido2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-fido2
Version:        1.2.0
Release:        1.1
Summary:        Python-based FIDO 2.0 library
License:        Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND MPL-2.0
Group:          Development/Languages/Python
URL:            https://github.com/Yubico/python-fido2
Source0:        https://github.com/Yubico/python-fido2/releases/download/%{version}/fido2-%{version}.tar.gz
Source1:        https://github.com/Yubico/python-fido2/releases/download/%{version}/fido2-%{version}.tar.gz.sig
Source2:        %{name}.keyring
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module cryptography >= 2.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.0}
BuildRequires:  %{python_module pyfakefs >= 3.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cryptography >= 2.6
BuildArch:      noarch
%python_subpackages

%description
This library supports the FIDO U2F and FIDO 2.0 protocols for communicating
with a USB authenticator via the Client-to-Authenticator Protocol (CTAP 1 and 2).
In addition to this low-level device access, classes defined in the fido2.client
implement higher level device operations.

%prep
%autosetup -p1 -n fido2-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%files %{python_files}
%doc NEWS* README*
%license COPYING*
%{python_sitelib}/fido2
%{python_sitelib}/fido2-%{version}*-info

%changelog
* Thu Jan  9 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.2.0:
  - Improved extension handling:
  - Several new extensions are now supported, both for Fido2Client
    and WindowsClient.
  - Extension APIs have been redesigned, and old APIs have been
    deprecated, slated for
  - removal in version 2.0.
  - Disable hmac-secret extension by default, preferring prf.
  - Improved (de-)serialization of dataclasses to/from
    JSON-friendly dicts.
  - Fido2Client:
  - Support allowCredentials/excludeCredentials of arbitrary
    length.
  - Handle PUAT_REQUIRED by re-attempting with PIN/UV.
  - Allow localhost (and subdomains) to use http:// in RP ID
    verification by default.
  - NFC: Support for Authenticators that return SW=61XX on SELECT.
  - USB: Improve connection recovery and use more specific
    exceptions for errors.
  - Fix: Handle residentKey=preferred properly.
  - Fix: Handle Authentictors that do not pass extensions in
    GetInfo.
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.3:
  * Fix USB HID issue on MacOS that sometimes caused a pause
    while waiting for a timeout.
  * Fix argument to CredProp extension where an enum value
    was required instead of also allowing a string.
  * Fix parsing of some key types (ES384, ES512) causing
    signature verification to fail.
  * Deprecation: Calling websafe_decode with a bytes argument
    instead of str.
    This will raise a TypeError in the next major version of
    the library.
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * Fix ClientPin usage for Authenticators that do not
    support passing a PIN.
  * Fix: Handle correct CTAP response codes in
    authenticatorSelection.
* Tue Jul  4 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon May  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * Bugfix: Don't set length for largeBlob when offset is 0.
  * Bugfix: Remove print statement in webauthn parsing.
* Thu Dec 15 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-six dependency
- More specific python_sitelib in %%files
* Mon Dec  5 2022 Torsten Gruner <simmphonie@opensuse.org>
- drop python-fido2-no-mock.patch
- Update to version 1.1.0
  * Bugfix: Fix name of "crossOrigin" in CollectedClientData.create().
  * Bugfix: Some incorrect type hints in the MDS3 classes were fixed.
  * Stricter checking of dataclass field types.
  * Add support for JSON-serialization of WebAuthn data classes.
    This changes the objects dict representation to align with new additions in the
    WebAuthn specification. As this may break compatibility, the new behavior
    requires explicit opt-in until python-fido2 2.0 is released.
  * Update server example to use JSON serialization.
  * Server: Add support for passing RegistrationResponse/AuthenticationResponse (or
    their deserialized JSON data) to register_complete/authenticate_complete.
  * Add new "hybrid" AuthenticatorTransport.
  * Add new AuthenticatorData flags, and use 2-letter names as in the WebAuthn spec
    (long names are still available as aliases).
- version 1.0.0
  * Release Candidate 1 of first stable release.
  * Require Python 3.7 or later.
  * APIs have updated to align with WebAuthn level 2.
  * Several CTAP 2.1 features have been implemented.
* Mon Mar 21 2022 pgajdos@suse.com
- do not require mock for build
- added patches
  fix https://github.com/Yubico/python-fido2/issues/135
  + python-fido2-no-mock.patch
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.3:
  * Don't fail device discovery when hidraw doesn't support HIDIOCGRAWUNIQ
  * Support the latest Windows webauthn.h API (included in Windows 11).
  * Add product name and serial number to HidDescriptors.
  * Remove the need for the uhid-freebsd dependency on FreeBSD.
- drop 0001-Don-t-use-enum.auto-Python-2.patch
    0001-Skip-tests-on-older-Cryptography-versions.patch (upstream)
* Tue May 25 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Thu May  6 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.9.1
  * Add new CTAP error codes and improve handling of unknown codes.
  * Client: API changes to better support extensions.
  * Client.make_credential now returns a AuthenticatorAttestationResponse,
    which holds the AttestationObject and ClientData, as well as any
    client extension results for the credential.
  * Client.get_assertion now returns an AssertionSelection object,
    which is used to select between multiple assertions
  * Renames: The CTAP1 and CTAP2 classes have been renamed to
    Ctap1 and Ctap2, respectively.
  * ClientPin: The ClientPin API has been restructured to support
    multiple PIN protocols, UV tokens, and token permissions.
  * CTAP 2.1 PRE: Several new features have been added for CTAP 2.1
  * HID: The platform specific HID code has been revamped
- Add 0001-Don-t-use-enum.auto-Python-2.patch from upstream
- Add 0001-Skip-tests-on-older-Cryptography-versions.patch from
  upstream
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Sun Dec  8 2019 Karol Babioch <kbabioch@suse.de>
- Version 0.8.1 (released 2019-11-25)
  * Bugfix: WindowsClient.make_credential error when resident key requirement is unspecified.
- Version 0.8.0 (released 2019-11-25)
  * New fido2.webauthn classes modeled after the W3C WebAuthn spec introduced.
  * CTAP2 send_cbor/make_credential/get_assertion and U2fClient request/authenticate timeout arguments replaced with event used to cancel a request.
  * Fido2Client:
  - make_credential/get_assertion now take WebAuthn options objects.
  - timeout is now provided in ms in WebAuthn options objects. Event based cancelation also available by passing an Event.
  * Fido2Server:
  - ATTESTATION, USER_VERIFICATION, and AUTHENTICATOR_ATTACHMENT enums have been replaced with fido2.webauthn classes.
  - RelyingParty has been replaced with PublicKeyCredentialRpEntity, and name is no longer optional.
  - Options returned by register_begin/authenticate_begin now omit unspecified values if they are optional, instead of filling in default values.
  - Fido2Server.allowed_algorithms now contains a list of PublicKeyCredentialParameters instead of algorithm identifiers.
  - Fido2Server.timeout is now in ms and of type int.
  * Support native WebAuthn API on Windows through WindowsClient.
- Version 0.7.3 (released 2019-10-24)
  j Bugfix: Workaround for size of int on Python 2 on Windows.
- Version 0.7.2 (released 2019-10-24)
  * Support for the TPM attestation format.
  * Allow passing custom challenges to register/authenticate in Fido2Server.
  * Bugfix: CTAP2 CANCEL command response handling fixed.
  * Bugfix: Fido2Client fix handling of empty allow_list.
  * Bugfix: Fix typo in CTAP2.get_assertions() causing it to fail.
- Version 0.7.1 (released 2019-09-20)
  * Support for FreeBSD.
  * Enforce canonical CBOR on Authenticator responses by default.
  * PCSC: Support extended APDUs.
  * Server: Verify that UP flag is set.
  * U2FFido2Server: Implement AppID exclusion extension.
  * U2FFido2Server: Allow custom U2F facet verification.
  * Bugfix: U2FFido2Server.authenticate_complete now returns the result.
* Mon Jun 17 2019 Karol Babioch <kbabioch@suse.de>
- Version 0.7.0 (released 2019-06-17)
  * Add support for NFC devices using PCSC.
  * Add support for the hmac-secret Authenticator extension.
  * Honor max credential ID length and number of credentials to Authenticator.
  * Add close() method to CTAP devices to explicitly release their resources.
* Fri May 10 2019 Karol Babioch <kbabioch@suse.de>
- Version 0.6.0 (released 2019-05-10)
  * Don't fail if CTAP2 Info contains unknown fields.
  * Replace cbor loads/dumps functions with encode/decode/decode_from.
  * Server: Add support for AuthenticatorAttachment.
  * Server: Add support for more key algorithms.
  * Client: Expose CTAP2 Info object as Fido2Client.info.
- Changed source URL to official release tarball
- Verifying signature of release tarball
* Fri Dec 21 2018 Karol Babioch <kbabioch@suse.de>
- Version 0.5.0 (released 2018-12-21)
  * Changes to server classes, some backwards breaking.
  * Add ability to authenticate U2F credentials by using the appid extension.
  * Make verification of attestation more explicit.
  * Add support for Android SafetyNet attestation.
  * Make it easier to work with U2F/CTAP1 data formats.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Sep 27 2018 Karol Babioch <kbabioch@suse.com>
- Version 0.4.0 (released 2018-09-27)
  - Add classes for implementing a server.
  - Various small changes, some affecting backwards compatibility.
* Sat Apr 21 2018 jengelh@inai.de
- Update descriptions.
* Tue Apr 17 2018 kbabioch@suse.com
- Initial packaging of version 0.3.0
